@@ -2,12 +2,14 @@ package UserAgent::Fake;
 
 use HTTP::Response::Maker HTTPResponse => ( prefix => 'HTTP_Response_' );
 
+my $HTTP_STATUS = HTTP_Response_OK;
+
 sub new{ my @requests; bless \@requests }
 
 sub request {
     my $self = shift;
     push @$self, @_;
-    return HTTP_Response_OK
+    return $HTTP_STATUS;
 }
 
 sub get_all_requests {
@@ -15,4 +17,9 @@ sub get_all_requests {
     return @$self
 }
 
+sub break_connection {
+    my $self = shift;
+    $HTTP_STATUS = HTTP_Response_SERVICE_UNAVAILABLE;
+}
+
 1;
